@@ -1,3 +1,13 @@
+import warnings
+
+
+def warning_on_one_line(message, category, filename, lineno, file=None, line=None):
+    return f"{filename}:{lineno}: {category.__name__}: {message}\n"
+
+
+warnings.formatwarning = warning_on_one_line
+
+
 class UndefinedObjectError(Exception):
     """Raised if an object is referenced within a lattice but no definition is found.
 
@@ -7,16 +17,23 @@ class UndefinedObjectError(Exception):
 
     def __init__(self, object_name, lattice_name):
         super().__init__(
-            f"The Object {object_name} is referenced in {lattice_name} "
+            f"The object '{object_name}' is referenced in '{lattice_name}' "
             "but no definition was found!"
         )
 
 
-class UnknownElementWarning(UserWarning):
+class IncompatibleVersionError(Exception):
+    """Raised if installed LatticeJSON library is out of date"""
+
+    def __init__(self, message):
+        super().__init__(f"Incompatible LatticeJSON version: {message}")
+
+
+class UnknownElementTypeWarning(UserWarning):
     """Raised if there is no equivalent LatticeJSON element."""
 
     def __init__(self, name, type_, *args, **kwargs):
-        message = f"Replacing element {name} ({type_}) with Drift."
+        message = f"Replacing element '{name}' ({type_}) with Drift."
         super().__init__(message, *args, **kwargs)
 
 
@@ -24,7 +41,7 @@ class UnknownAttributeWarning(UserWarning):
     """Raised if there is no equivalent LatticeJSON attribute."""
 
     def __init__(self, attribute, element, *args, **kwargs):
-        message = f"Ignoring attribute {attribute} of {element}."
+        message = f"Ignoring attribute '{attribute}' of '{element}'."
         super().__init__(message, *args, **kwargs)
 
 
